@@ -529,22 +529,9 @@ class EstimatedBathymetryPoints:
         f"{len(points_files)} points files and {len(type_labels)} type labels"
 
         # Points - rename depth labels to standard if a non standard one is specified
-        points_i = geopandas.read_file(points_files[0])
-        points_i[self.TYPE_LABEL] = type_labels[0]
-        if z_labels is not None:
-            points_i = points_i.rename(columns={z_labels[0]: self.DEPTH_LABEL})
-        columns_i = [self.DEPTH_LABEL, self.TYPE_LABEL, "geometry"]
-        if self.BANK_HEIGHT_LABEL in points_i.columns:
-            columns_i.append(self.BANK_HEIGHT_LABEL)
-        if self.WIDTH_LABEL in points_i.columns:
-            columns_i.append(self.WIDTH_LABEL)
-        points_i = points_i[columns_i]
-        points_list = [points_i]
-        # Polygon where the points are relevent
-        polygon_i = geopandas.read_file(polygon_files[0])
-        polygon_i[self.TYPE_LABEL] = type_labels[0]
-        polygon_list = [polygon_i]
-        for i in range(1, len(points_files)):
+        points_list = []
+        polygon_list = []
+        for i in range(0, len(points_files)):
             # Points - rename depth labels to standard if  specified
             points_i = geopandas.read_file(points_files[i])
             points_i[self.TYPE_LABEL] = type_labels[i]
@@ -555,12 +542,14 @@ class EstimatedBathymetryPoints:
                 columns_i.append(self.BANK_HEIGHT_LABEL)
             if self.WIDTH_LABEL in points_i.columns:
                 columns_i.append(self.WIDTH_LABEL)
-            points_i = points_i[columns_i]
-            points_list.append(points_i)
-            # Polygon where the points are relevent
-            polygon_i = geopandas.read_file(polygon_files[i])
-            polygon_i[self.TYPE_LABEL] = type_labels[i]
-            polygon_list.append(polygon_i)
+            # Only add the points and polygons if their are points
+            if len(points_i) > 0:
+                points_i = points_i[columns_i]
+                points_list.append(points_i)
+                # Polygon where the points are relevent
+                polygon_i = geopandas.read_file(polygon_files[i])
+                polygon_i[self.TYPE_LABEL] = type_labels[i]
+                polygon_list.append(polygon_i)
         # Set CRS, clip to size and reset index
         points = geopandas.GeoDataFrame(
             pandas.concat(points_list, ignore_index=True), crs=points_list[0].crs
@@ -620,6 +609,15 @@ class EstimatedBathymetryPoints:
             ).to_list()
         return points_array
 
+    def bank_heights_exist(self, type_label: str) -> bool:
+        """Return true if the bank heights are defined in array"""
+        return (
+            self.BANK_HEIGHT_LABEL in self._points.columns
+            and self._points[self._points["type"] == type_label][
+                self.BANK_HEIGHT_LABEL
+            ].any()
+        )
+
     def filtered_bank_height_points(self, type_label: str = None) -> numpy.ndarray:
         """Return the points with 'Z' being the estimated bank height as a single array."""
 
@@ -753,8 +751,6 @@ class RiverMouthFan:
 
     FAN_ANGLE = 30
     FAN_MAX_LENGTH = 10_000
-    ELEVATION_LABEL_1 = "bed_elevation_Neal_et_al"
-    ELEVATION_LABEL_2 = "bed_elevation_Rupp_and_Smart"
 
     def __init__(
         self,
@@ -764,6 +760,7 @@ class RiverMouthFan:
         ocean_contour_file: str,
         crs: int,
         cross_section_spacing: float,
+        elevation_labels: list,
         ocean_contour_depth_label: str = None,
     ):
         self.crs = crs
@@ -773,6 +770,7 @@ class RiverMouthFan:
         self.river_bathymetry_file = river_bathymetry_file
         self.ocean_contour_file = ocean_contour_file
         self.ocean_contour_depth_label = ocean_contour_depth_label
+        self.elevation_labels = elevation_labels
 
     def _get_mouth_alignment(self):
         """Get the location and alignment of the river mouth."""
@@ -812,10 +810,12 @@ class RiverMouthFan:
             river_polygon.buffer(self.cross_section_spacing / 2)
         ).sort_index(ascending=True)
 
-        river_mouth_elevation_1 = river_bathymetry[self.ELEVATION_LABEL_1].iloc[0]
-        river_mouth_elevation_2 = river_bathymetry[self.ELEVATION_LABEL_2].iloc[0]
+        river_mouth_elevations = [
+            river_bathymetry[elevation_label].iloc[0]
+            for elevation_label in self.elevation_labels
+        ]
         river_mouth_width = river_bathymetry["width"].iloc[0]
-        return river_mouth_width, [river_mouth_elevation_1, river_mouth_elevation_2]
+        return river_mouth_width, river_mouth_elevations
 
     def _get_ocean_contours(
         self, river_mouth_depth, depth_sign: int = -1, depth_multiplier: int = 2
@@ -883,14 +883,13 @@ class RiverMouthFan:
 
         # Setup the fan data values
         fan_depths = {
-            "geometry": [],
-            self.ELEVATION_LABEL_1: [],
-            self.ELEVATION_LABEL_2: [],
+            **{"geometry": []},
+            **dict((elevation_label, []) for elevation_label in self.elevation_labels),
         }
         number_of_samples = int(distance / self.cross_section_spacing)
         depth_increments = [
-            (-1 * end_depth - river_mouth_elevations[0]) / number_of_samples,
-            (-1 * end_depth - river_mouth_elevations[1]) / number_of_samples,
+            (-1 * end_depth - river_mouth_elevation) / number_of_samples
+            for river_mouth_elevation in river_mouth_elevations
         ]
 
         # Iterate through creating fan bathymetry
@@ -905,12 +904,12 @@ class RiverMouthFan:
                     ]
                 )
             )
-            fan_depths[self.ELEVATION_LABEL_1].append(
-                river_mouth_elevations[0] + i * depth_increments[0]
-            )
-            fan_depths[self.ELEVATION_LABEL_2].append(
-                river_mouth_elevations[1] + i * depth_increments[1]
-            )
+            for elevation_label, river_mouth_elevation, depth_increment in zip(
+                self.elevation_labels, river_mouth_elevations, depth_increments
+            ):
+                fan_depths[elevation_label].append(
+                    river_mouth_elevation + i * depth_increment
+                )
         fan_depths = geopandas.GeoDataFrame(fan_depths, crs=self.crs)
         return fan_depths
 
